#!/bin/sh
#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2013. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT

setWASHome()
{
    if [ "${REPLACE_WAS_HOME:=}" != "" ] && [ -d ${REPLACE_WAS_HOME} ]
    then
        WAS_HOME=${REPLACE_WAS_HOME}
    else
        CUR_DIR=`pwd`
        WAS_DIR=`dirname ${0}`/../
        cd "${WAS_DIR}"
        WAS_HOME=`pwd`
        #cd "${CUR_DIR}"
    fi
}
setWASHome

#binDir=`dirname "$0"`
#cd $binDir

JAVA_HOME=$WAS_HOME/java

LOGGING_PROPS=-Djava.util.logging.config.file="$WAS_HOME/util/migration/resources/logging.properties"
LOGGING_FILTER_PROP="-Dcom.ibm.bpm.migration.logging.StringFilter.excludes=equals(WSVR0072W);equals(WSVR0801I);equals(WKSP0500);equals(CWWMH0110E);equals(ADMC0046W);equals(SIB_MESSAGE);equals(SOME_FUTURE_MESSAGES_SUPPRESSED_CWSIU0005);equals(chain.started);contains(tmx4jTransform.jar)"

SSL_PROPS=-Dcom.ibm.SSL.ConfigURL=file:///$WAS_HOME/util/migration/resources/ssl.client.props
SOAP_CLIENT_PROPS=-Dcom.ibm.SOAP.ConfigURL=file:///$WAS_HOME/util/migration/resources/soap.client.props

COMMAND_NAME=`basename $0`
COMMAND_NAME="${COMMAND_NAME%.*}"
COMMAND_NAME_PROPS=-Dmig.command.name="${COMMAND_NAME}"

PARAMS="$@"
while [ $# -gt 0 ]; do
  if [ $1 = "-backupFolder" ];
  then
        snapshotRoot=$2;
        break;
  else
        shift;
  fi
done
SNAPSHOT_ROOT_PROPS=-Dmig.snapshot.root="$snapshotRoot"

ENABLE_DEBUG=false
if [ $ENABLE_DEBUG = true ]; then
   DEBUG_PROP="-agentlib:jdwp=transport=dt_socket,server=y,suspend=y,address=9999"
else
   DEBUG_PROP=
fi

PLATFORM=`/bin/uname`
case $PLATFORM in
  AIX)
    WAS_LIBPATH="$JAVA_NATIVE_LIB_DIR":"$WAS_HOME"/bin
    WAS_EXT_DIRS="$JAVA_HOME"/lib:"$WAS_HOME"/classes:"$WAS_HOME"/lib:"$WAS_HOME"/installedChannels:"$WAS_HOME"/lib/ext
	JAVA_EXT_PROP=-Djava.ext.dirs="$JAVA_HOME/jre/lib/ext:$WAS_EXT_DIRS:$WAS_HOME/plugins:$WAS_HOME/lib/WMQ/java/lib"
    NLSPATH=/usr/lib/nls/msg/%L/%N:/usr/lib/nls/msg/en_US/%N:${NLSPATH:=}
    ;;
  Linux)
    WAS_LIBPATH="$JAVA_NATIVE_LIB_DIR":"$WAS_HOME"/bin
    WAS_EXT_DIRS="$JAVA_HOME"/lib:"$WAS_HOME"/classes:"$WAS_HOME"/lib:"$WAS_HOME"/installedChannels:"$WAS_HOME"/lib/ext
	JAVA_EXT_PROP=-Djava.ext.dirs="$JAVA_HOME/jre/lib/ext:$WAS_EXT_DIRS:$WAS_HOME/plugins:$WAS_HOME/lib/WMQ/java/lib"
    NLSPATH=/usr/lib/locale/%L/LC_MESSAGES/%N:${NLSPATH:=}
    JAVA_HIGH_ZIPFDS=200
    ;;
  SunOS)
    if [ "$LANG" = "" ]
    then
       LANG=C
       export LANG
    fi
    WAS_LIBPATH="$JAVA_NATIVE_LIB_DIR":"$WAS_HOME"/bin
    WAS_EXT_DIRS="$JAVA_HOME"/lib:"$WAS_HOME"/classes:"$WAS_HOME"/lib:"$WAS_HOME"/installedChannels:"$WAS_HOME"/lib/ext
	JAVA_EXT_PROP=-Djava.ext.dirs="$JAVA_HOME/jre/lib/ext:$WAS_EXT_DIRS:$WAS_HOME/plugins:$WAS_HOME/lib/WMQ/java/lib"
    NLSPATH=/usr/lib/locale/%L/LC_MESSAGES/%N:${NLSPATH:=}
    if [ $ARCH = "i86pc" ]
    then
      JVM_EXTRA_CMD_ARGS=-d64
    else
       file "$JAVA_NATIVE_LIB_DIR/libWs60ProcessManagement.so" | grep "ELF 64" > /dev/null
       if [ $? = 0 -a -d $JAVA_HOME/jre/bin/sparcv9 ];then
          JVM_EXTRA_CMD_ARGS=-d64
       fi
    fi
    ;;
  HP-UX)
    WAS_LIBPATH="$JAVA_NATIVE_LIB_DIR":"$WAS_HOME"/bin
    WAS_EXT_DIRS="$JAVA_HOME"/lib:"$WAS_HOME"/classes:"$WAS_HOME"/lib:"$WAS_HOME"/installedChannels:"$WAS_HOME"/lib/ext
	JAVA_EXT_PROP=-Djava.ext.dirs="$JAVA_HOME/jre/lib/ext:$WAS_EXT_DIRS:$WAS_HOME/plugins:$WAS_HOME/lib/WMQ/java/lib"
    NLSPATH=/usr/lib/nls/msg/%L/%N:${NLSPATH:=}
    if [ "$ARCH" = "ia64" ]
    then
      JVM_EXTRA_CMD_ARGS="-d64 -Djava.net.preferIPv4Stack=false"
    else
      JVM_EXTRA_CMD_ARGS=-Djava.net.preferIPv4Stack=false
    fi
    ;;
  OS/390)
    LIBPATH=$LIBPATH:"$WAS_HOME"/patches:"$WAS_HOME"/lib/s390x-64:"$WAS_HOME"/lib/s390-31:"$WAS_HOME"/lib/s390-common
    WAS_LIBPATH="$WAS_HOME"/bin    
    NLSPATH=/usr/lib/locale/%L/LC_MESSAGES/%N:${NLSPATH:=}
    WAS_CLASSPATH="$WAS_CLASSPATH":"$WAS_HOME"/lib/bootstrapws390.jar
    JVM_EXTRA_CMD_ARGS="-Djava.security.properties=$WAS_HOME/properties/java.security"    
    WAS_EXT_DIRS="$JAVA_HOME"/lib:"$WAS_HOME"/classes:"$WAS_HOME"/lib:"$WAS_HOME"/installedChannels:"$WAS_HOME"/lib/ext
	JAVA_EXT_PROP=-Djava.ext.dirs="$JAVA_HOME/jre/lib/ext:$JAVA_HOME/lib/ext:$WAS_EXT_DIRS:$WAS_HOME/plugins:$WAS_HOME/lib/WMQ/java/lib"
    ;;
  *)
    LIBPATH=$LIBPATH:"$WAS_HOME"/lib    
    ;;
esac

"$JAVA_HOME/bin/java" \
$DEBUG_PROP \
-Dwas.install.root="$WAS_HOME" \
$JAVA_EXT_PROP \
$LOGGING_PROPS \
$LOGGING_FILTER_PROP \
$SSL_PROPS \
$SOAP_CLIENT_PROPS \
"$SNAPSHOT_ROOT_PROPS" \
$COMMAND_NAME_PROPS \
-classpath "$WAS_HOME"/plugins/com.ibm.bpm.config.jar:"$WAS_HOME"/BPM/Lombardi/lib/jdom.jar \
com.ibm.bpm.migration.BPMMigration -migrate $PARAMS
